import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent, PromiseOrValue } from "./common";
export interface IWormholeReceiverInterface extends utils.Interface {
    functions: {
        "receiveWormholeMessages(bytes,bytes[],bytes32,uint16,bytes32)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "receiveWormholeMessages"): FunctionFragment;
    encodeFunctionData(functionFragment: "receiveWormholeMessages", values: [
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BytesLike>[],
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>
    ]): string;
    decodeFunctionResult(functionFragment: "receiveWormholeMessages", data: BytesLike): Result;
    events: {};
}
export interface IWormholeReceiver extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IWormholeReceiverInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        receiveWormholeMessages(payload: PromiseOrValue<BytesLike>, additionalMessages: PromiseOrValue<BytesLike>[], sourceAddress: PromiseOrValue<BytesLike>, sourceChain: PromiseOrValue<BigNumberish>, deliveryHash: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
    };
    receiveWormholeMessages(payload: PromiseOrValue<BytesLike>, additionalMessages: PromiseOrValue<BytesLike>[], sourceAddress: PromiseOrValue<BytesLike>, sourceChain: PromiseOrValue<BigNumberish>, deliveryHash: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        receiveWormholeMessages(payload: PromiseOrValue<BytesLike>, additionalMessages: PromiseOrValue<BytesLike>[], sourceAddress: PromiseOrValue<BytesLike>, sourceChain: PromiseOrValue<BigNumberish>, deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
    };
    filters: {};
    estimateGas: {
        receiveWormholeMessages(payload: PromiseOrValue<BytesLike>, additionalMessages: PromiseOrValue<BytesLike>[], sourceAddress: PromiseOrValue<BytesLike>, sourceChain: PromiseOrValue<BigNumberish>, deliveryHash: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        receiveWormholeMessages(payload: PromiseOrValue<BytesLike>, additionalMessages: PromiseOrValue<BytesLike>[], sourceAddress: PromiseOrValue<BytesLike>, sourceChain: PromiseOrValue<BigNumberish>, deliveryHash: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
    };
}
