import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent, PromiseOrValue } from "./common";
export declare type VaaKeyStruct = {
    chainId: PromiseOrValue<BigNumberish>;
    emitterAddress: PromiseOrValue<BytesLike>;
    sequence: PromiseOrValue<BigNumberish>;
};
export declare type VaaKeyStructOutput = [number, string, BigNumber] & {
    chainId: number;
    emitterAddress: string;
    sequence: BigNumber;
};
export declare type MessageKeyStruct = {
    keyType: PromiseOrValue<BigNumberish>;
    encodedKey: PromiseOrValue<BytesLike>;
};
export declare type MessageKeyStructOutput = [number, string] & {
    keyType: number;
    encodedKey: string;
};
export interface WormholeRelayerSendInterface extends utils.Interface {
    functions: {
        "deliveryAttempted(bytes32)": FunctionFragment;
        "deliveryFailureBlock(bytes32)": FunctionFragment;
        "deliverySuccessBlock(bytes32)": FunctionFragment;
        "forward(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)": FunctionFragment;
        "forwardPayloadToEvm(uint16,address,bytes,uint256,uint256)": FunctionFragment;
        "forwardToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)": FunctionFragment;
        "forwardVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])": FunctionFragment;
        "getDefaultDeliveryProvider()": FunctionFragment;
        "getRegisteredWormholeRelayerContract(uint16)": FunctionFragment;
        "quoteDeliveryPrice(uint16,uint256,bytes,address)": FunctionFragment;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)": FunctionFragment;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256)": FunctionFragment;
        "quoteNativeForChain(uint16,uint256,address)": FunctionFragment;
        "resend((uint16,bytes32,uint64),uint16,uint256,bytes,address)": FunctionFragment;
        "resendToEvm((uint16,bytes32,uint64),uint16,uint256,uint256,address)": FunctionFragment;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)": FunctionFragment;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)": FunctionFragment;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)": FunctionFragment;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)": FunctionFragment;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)": FunctionFragment;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)": FunctionFragment;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])": FunctionFragment;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "deliveryAttempted" | "deliveryFailureBlock" | "deliverySuccessBlock" | "forward" | "forwardPayloadToEvm" | "forwardToEvm" | "forwardVaasToEvm" | "getDefaultDeliveryProvider" | "getRegisteredWormholeRelayerContract" | "quoteDeliveryPrice" | "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)" | "quoteEVMDeliveryPrice(uint16,uint256,uint256)" | "quoteNativeForChain" | "resend" | "resendToEvm" | "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)" | "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)" | "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)" | "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)" | "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)" | "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)" | "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])" | "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)"): FunctionFragment;
    encodeFunctionData(functionFragment: "deliveryAttempted", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "deliveryFailureBlock", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "deliverySuccessBlock", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "forward", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>,
        VaaKeyStruct[],
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "forwardPayloadToEvm", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "forwardToEvm", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<string>,
        VaaKeyStruct[],
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "forwardVaasToEvm", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        VaaKeyStruct[]
    ]): string;
    encodeFunctionData(functionFragment: "getDefaultDeliveryProvider", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRegisteredWormholeRelayerContract", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "quoteDeliveryPrice", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>
    ]): string;
    encodeFunctionData(functionFragment: "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>
    ]): string;
    encodeFunctionData(functionFragment: "quoteEVMDeliveryPrice(uint16,uint256,uint256)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "quoteNativeForChain", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>
    ]): string;
    encodeFunctionData(functionFragment: "resend", values: [
        VaaKeyStruct,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>
    ]): string;
    encodeFunctionData(functionFragment: "resendToEvm", values: [
        VaaKeyStruct,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>
    ]): string;
    encodeFunctionData(functionFragment: "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>,
        VaaKeyStruct[],
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>,
        MessageKeyStruct[],
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>
    ]): string;
    encodeFunctionData(functionFragment: "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<string>,
        VaaKeyStruct[],
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<string>,
        MessageKeyStruct[],
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        VaaKeyStruct[]
    ]): string;
    encodeFunctionData(functionFragment: "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>,
        VaaKeyStruct[],
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<string>
    ]): string;
    decodeFunctionResult(functionFragment: "deliveryAttempted", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "deliveryFailureBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "deliverySuccessBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "forward", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "forwardPayloadToEvm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "forwardToEvm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "forwardVaasToEvm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getDefaultDeliveryProvider", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRegisteredWormholeRelayerContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "quoteDeliveryPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "quoteEVMDeliveryPrice(uint16,uint256,uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "quoteNativeForChain", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "resend", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "resendToEvm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)", data: BytesLike): Result;
    events: {
        "SendEvent(uint64,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "SendEvent"): EventFragment;
}
export interface SendEventEventObject {
    sequence: BigNumber;
    deliveryQuote: BigNumber;
    paymentForExtraReceiverValue: BigNumber;
}
export declare type SendEventEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    BigNumber
], SendEventEventObject>;
export declare type SendEventEventFilter = TypedEventFilter<SendEventEvent>;
export interface WormholeRelayerSend extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: WormholeRelayerSendInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        deliveryAttempted(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[boolean] & {
            attempted: boolean;
        }>;
        deliveryFailureBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[BigNumber] & {
            blockNumber: BigNumber;
        }>;
        deliverySuccessBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[BigNumber] & {
            blockNumber: BigNumber;
        }>;
        forward(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, arg4: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        forwardPayloadToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        forwardToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        forwardVaasToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        getDefaultDeliveryProvider(overrides?: CallOverrides): Promise<[string] & {
            deliveryProvider: string;
        }>;
        getRegisteredWormholeRelayerContract(chainId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[string]>;
        quoteDeliveryPrice(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[
            BigNumber,
            string
        ] & {
            nativePriceQuote: BigNumber;
            encodedExecutionInfo: string;
        }>;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            nativePriceQuote: BigNumber;
            targetChainRefundPerGasUnused: BigNumber;
        }>;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            nativePriceQuote: BigNumber;
            targetChainRefundPerGasUnused: BigNumber;
        }>;
        quoteNativeForChain(targetChain: PromiseOrValue<BigNumberish>, currentChainAmount: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[BigNumber] & {
            targetChainAmount: BigNumber;
        }>;
        resend(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newEncodedExecutionParameters: PromiseOrValue<BytesLike>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        resendToEvm(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newGasLimit: PromiseOrValue<BigNumberish>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
    };
    deliveryAttempted(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
    deliveryFailureBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
    deliverySuccessBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
    forward(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, arg4: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    forwardPayloadToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    forwardToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    forwardVaasToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    getDefaultDeliveryProvider(overrides?: CallOverrides): Promise<string>;
    getRegisteredWormholeRelayerContract(chainId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
    quoteDeliveryPrice(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[
        BigNumber,
        string
    ] & {
        nativePriceQuote: BigNumber;
        encodedExecutionInfo: string;
    }>;
    "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[
        BigNumber,
        BigNumber
    ] & {
        nativePriceQuote: BigNumber;
        targetChainRefundPerGasUnused: BigNumber;
    }>;
    "quoteEVMDeliveryPrice(uint16,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[
        BigNumber,
        BigNumber
    ] & {
        nativePriceQuote: BigNumber;
        targetChainRefundPerGasUnused: BigNumber;
    }>;
    quoteNativeForChain(targetChain: PromiseOrValue<BigNumberish>, currentChainAmount: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    resend(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newEncodedExecutionParameters: PromiseOrValue<BytesLike>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    resendToEvm(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newGasLimit: PromiseOrValue<BigNumberish>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        deliveryAttempted(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
        deliveryFailureBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        deliverySuccessBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        forward(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, arg4: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<void>;
        forwardPayloadToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<void>;
        forwardToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<void>;
        forwardVaasToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: CallOverrides): Promise<void>;
        getDefaultDeliveryProvider(overrides?: CallOverrides): Promise<string>;
        getRegisteredWormholeRelayerContract(chainId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
        quoteDeliveryPrice(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[
            BigNumber,
            string
        ] & {
            nativePriceQuote: BigNumber;
            encodedExecutionInfo: string;
        }>;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            nativePriceQuote: BigNumber;
            targetChainRefundPerGasUnused: BigNumber;
        }>;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            nativePriceQuote: BigNumber;
            targetChainRefundPerGasUnused: BigNumber;
        }>;
        quoteNativeForChain(targetChain: PromiseOrValue<BigNumberish>, currentChainAmount: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        resend(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newEncodedExecutionParameters: PromiseOrValue<BytesLike>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        resendToEvm(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newGasLimit: PromiseOrValue<BigNumberish>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: CallOverrides): Promise<BigNumber>;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {
        "SendEvent(uint64,uint256,uint256)"(sequence?: PromiseOrValue<BigNumberish> | null, deliveryQuote?: null, paymentForExtraReceiverValue?: null): SendEventEventFilter;
        SendEvent(sequence?: PromiseOrValue<BigNumberish> | null, deliveryQuote?: null, paymentForExtraReceiverValue?: null): SendEventEventFilter;
    };
    estimateGas: {
        deliveryAttempted(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        deliveryFailureBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        deliverySuccessBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        forward(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, arg4: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        forwardPayloadToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        forwardToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        forwardVaasToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        getDefaultDeliveryProvider(overrides?: CallOverrides): Promise<BigNumber>;
        getRegisteredWormholeRelayerContract(chainId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        quoteDeliveryPrice(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        quoteNativeForChain(targetChain: PromiseOrValue<BigNumberish>, currentChainAmount: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        resend(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newEncodedExecutionParameters: PromiseOrValue<BytesLike>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        resendToEvm(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newGasLimit: PromiseOrValue<BigNumberish>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        deliveryAttempted(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        deliveryFailureBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        deliverySuccessBlock(deliveryHash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        forward(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, arg4: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        forwardPayloadToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        forwardToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        forwardVaasToEvm(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        getDefaultDeliveryProvider(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRegisteredWormholeRelayerContract(chainId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        quoteDeliveryPrice(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256,address)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "quoteEVMDeliveryPrice(uint16,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        quoteNativeForChain(targetChain: PromiseOrValue<BigNumberish>, currentChainAmount: PromiseOrValue<BigNumberish>, deliveryProviderAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        resend(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newEncodedExecutionParameters: PromiseOrValue<BytesLike>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        resendToEvm(deliveryVaaKey: VaaKeyStruct, targetChain: PromiseOrValue<BigNumberish>, newReceiverValue: PromiseOrValue<BigNumberish>, newGasLimit: PromiseOrValue<BigNumberish>, newDeliveryProviderAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "send(uint16,bytes32,bytes,uint256,uint256,bytes,uint16,bytes32,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<BytesLike>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, encodedExecutionParameters: PromiseOrValue<BytesLike>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<BytesLike>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256,uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "sendPayloadToEvm(uint16,address,bytes,uint256,uint256)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint16,bytes32,uint64)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, vaaKeys: VaaKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "sendToEvm(uint16,address,bytes,uint256,uint256,uint256,uint16,address,address,(uint8,bytes)[],uint8)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, paymentForExtraReceiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, deliveryProviderAddress: PromiseOrValue<string>, messageKeys: MessageKeyStruct[], consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[])"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        "sendVaasToEvm(uint16,address,bytes,uint256,uint256,(uint16,bytes32,uint64)[],uint16,address)"(targetChain: PromiseOrValue<BigNumberish>, targetAddress: PromiseOrValue<string>, payload: PromiseOrValue<BytesLike>, receiverValue: PromiseOrValue<BigNumberish>, gasLimit: PromiseOrValue<BigNumberish>, vaaKeys: VaaKeyStruct[], refundChain: PromiseOrValue<BigNumberish>, refundAddress: PromiseOrValue<string>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
    };
}
